from datetime import datetime
import pytz


class Transformations:
    def date_to_utc(self, epoch=None, date_local=None) -> str:
        """Function to convert date epoch and local time to UTC.

        Args:
            epoch (int, optional): Epoch timestamp. Defaults to None.
            date_local (datetime, optional): Local datetime. Defaults to None.

        Returns:
            str: Datetime in UTC format parsed to string.
        """
        if epoch is not None:
            local = pytz.timezone("America/Mexico_City")
            local_time = datetime.utcfromtimestamp(epoch / 1000)
            local_dt = local.localize(local_time, is_dst=None)
            utc_dt = local_dt.astimezone(pytz.utc)
            return utc_dt.strftime("%Y-%m-%dT%H:%M:%SZ")

        if date_local is not None:
            return date_local.strftime("%Y-%m-%dT%H:%M:%SZ")

        if epoch is None and date_local is None:
            return datetime.utcnow().strftime("%Y-%m-%dT%H:%M:%SZ")



# pytype: skip-file

import subprocess
from distutils.command.build import build as _build  # type: ignore

import setuptools


REQUIRED_PACKAGES = []

# This call to setup() does all the work
setuptools.setup(
    name="ivoy_de",
    version="0.0.1",
    description="Perform transformations for batch and streaming data",
    author="Carlos Lopez",
    author_email="carlos.lopez@ivoy.mx",
    install_requires=REQUIRED_PACKAGES,
    packages=setuptools.find_packages(),
)
